@@ -103,108 +103,108 @@ def n_local(
 
     Entanglement:
 
-        The entanglement describes the connections of the gates in the entanglement layer.
-        For a two-qubit gate for example, the entanglement contains pairs of qubits on which the
-        gate should acts, e.g. ``[[ctrl0, target0], [ctrl1, target1], ...]``.
-        A set of default entanglement strategies is provided and can be selected by name:
+    The entanglement describes the connections of the gates in the entanglement layer.
+    For a two-qubit gate for example, the entanglement contains pairs of qubits on which the
+    gate should acts, e.g. ``[[ctrl0, target0], [ctrl1, target1], ...]``.
+    A set of default entanglement strategies is provided and can be selected by name:
 
-        * ``"full"`` entanglement is each qubit is entangled with all the others.
-        * ``"linear"`` entanglement is qubit :math:`i` entangled with qubit :math:`i + 1`,
-          for all :math:`i \in \{0, 1, ... , n - 2\}`, where :math:`n` is the total number of qubits.
-        * ``"reverse_linear"`` entanglement is qubit :math:`i` entangled with qubit :math:`i + 1`,
-          for all :math:`i \in \{n-2, n-3, ... , 1, 0\}`, where :math:`n` is the total number of qubits.
-          Note that if ``entanglement_blocks=="cx"`` then this option provides the same unitary as
-          ``"full"`` with fewer entangling gates.
-        * ``"pairwise"`` entanglement is one layer where qubit :math:`i` is entangled with qubit
-          :math:`i + 1`, for all even values of :math:`i`, and then a second layer where qubit :math:`i`
-          is entangled with qubit :math:`i + 1`, for all odd values of :math:`i`.
-        * ``"circular"`` entanglement is linear entanglement but with an additional entanglement of the
-          first and last qubit before the linear part.
-        * ``"sca"`` (shifted-circular-alternating) entanglement is a generalized and modified version
-          of the proposed circuit 14 in `Sim et al. <https://arxiv.org/abs/1905.10876>`__.
-          It consists of circular entanglement where the "long" entanglement connecting the first with
-          the last qubit is shifted by one each block.  Furthermore the role of control and target
-          qubits are swapped every block (therefore alternating).
+    * ``"full"`` entanglement is each qubit is entangled with all the others.
+    * ``"linear"`` entanglement is qubit :math:`i` entangled with qubit :math:`i + 1`,
+        for all :math:`i \in \{0, 1, ... , n - 2\}`, where :math:`n` is the total number of qubits.
+    * ``"reverse_linear"`` entanglement is qubit :math:`i` entangled with qubit :math:`i + 1`,
+        for all :math:`i \in \{n-2, n-3, ... , 1, 0\}`, where :math:`n` is the total number of qubits.
+        Note that if ``entanglement_blocks=="cx"`` then this option provides the same unitary as
+        ``"full"`` with fewer entangling gates.
+    * ``"pairwise"`` entanglement is one layer where qubit :math:`i` is entangled with qubit
+        :math:`i + 1`, for all even values of :math:`i`, and then a second layer where qubit :math:`i`
+        is entangled with qubit :math:`i + 1`, for all odd values of :math:`i`.
+    * ``"circular"`` entanglement is linear entanglement but with an additional entanglement of the
+        first and last qubit before the linear part.
+    * ``"sca"`` (shifted-circular-alternating) entanglement is a generalized and modified version
+        of the proposed circuit 14 in `Sim et al. <https://arxiv.org/abs/1905.10876>`__.
+        It consists of circular entanglement where the "long" entanglement connecting the first with
+        the last qubit is shifted by one each block.  Furthermore the role of control and target
+        qubits are swapped every block (therefore alternating).
 
-        If an entanglement layer contains multiple blocks, then the entanglement should be
-        given as list of entanglements for each block. For example::
+    If an entanglement layer contains multiple blocks, then the entanglement should be
+    given as list of entanglements for each block. For example::
 
-            entanglement_blocks = ["rxx", "ryy"]
-            entanglement = ["full", "linear"]  # full for rxx and linear for ryy
+        entanglement_blocks = ["rxx", "ryy"]
+        entanglement = ["full", "linear"]  # full for rxx and linear for ryy
 
-        or::
+    or::
 
-            structure_rxx = [[0, 1], [2, 3]]
-            structure_ryy = [[0, 2]]
-            entanglement = [structure_rxx, structure_ryy]
+        structure_rxx = [[0, 1], [2, 3]]
+        structure_ryy = [[0, 2]]
+        entanglement = [structure_rxx, structure_ryy]
 
-        Finally, the entanglement can vary in each repetition of the circuit. For this, we
-        support passing a callable that takes as input the layer index and returns the entanglement
-        for the layer in the above format. See the examples below for a concrete example.
+    Finally, the entanglement can vary in each repetition of the circuit. For this, we
+    support passing a callable that takes as input the layer index and returns the entanglement
+    for the layer in the above format. See the examples below for a concrete example.
 
     Examples:
 
-        The rotation and entanglement gates can be specified via single strings, if they
-        are made up of a single block per layer:
+    The rotation and entanglement gates can be specified via single strings, if they
+    are made up of a single block per layer:
 
-        .. plot::
-            :alt: Circuit diagram output by the previous code.
-            :include-source:
-            :context:
+    .. plot::
+        :alt: Circuit diagram output by the previous code.
+        :include-source:
+        :context:
 
-            from qiskit.circuit.library import n_local
+        from qiskit.circuit.library import n_local
 
-            circuit = n_local(3, "ry", "cx", "linear", reps=2, insert_barriers=True)
-            circuit.draw("mpl")
+        circuit = n_local(3, "ry", "cx", "linear", reps=2, insert_barriers=True)
+        circuit.draw("mpl")
 
-        Multiple gates per layer can be set by passing a list. Here, for example, we use
-        Pauli-Y and Pauli-Z rotations in the rotation layer:
+    Multiple gates per layer can be set by passing a list. Here, for example, we use
+    Pauli-Y and Pauli-Z rotations in the rotation layer:
 
-        .. plot::
-            :alt: Circuit diagram output by the previous code.
-            :include-source:
-            :context: close-figs
+    .. plot::
+        :alt: Circuit diagram output by the previous code.
+        :include-source:
+        :context: close-figs
 
-            circuit = n_local(3, ["ry", "rz"], "cz", "full", reps=1, insert_barriers=True)
-            circuit.draw("mpl")
+        circuit = n_local(3, ["ry", "rz"], "cz", "full", reps=1, insert_barriers=True)
+        circuit.draw("mpl")
 
-        To omit rotation or entanglement layers, the block can be set to an empty list:
+    To omit rotation or entanglement layers, the block can be set to an empty list:
 
-        .. plot::
-            :alt: Circuit diagram output by the previous code.
-            :include-source:
-            :context: close-figs
+    .. plot::
+        :alt: Circuit diagram output by the previous code.
+        :include-source:
+        :context: close-figs
 
-            circuit = n_local(4, [], "cry", reps=2)
-            circuit.draw("mpl")
+        circuit = n_local(4, [], "cry", reps=2)
+        circuit.draw("mpl")
 
-        The entanglement can be set explicitly via the ``entanglement`` argument:
+    The entanglement can be set explicitly via the ``entanglement`` argument:
 
-        .. plot::
-            :alt: Circuit diagram output by the previous code.
-            :include-source:
-            :context: close-figs
+    .. plot::
+        :alt: Circuit diagram output by the previous code.
+        :include-source:
+        :context: close-figs
 
-            entangler_map = [[0, 1], [2, 0]]
-            circuit = n_local(3, "x", "crx", entangler_map, reps=2)
-            circuit.draw("mpl")
+        entangler_map = [[0, 1], [2, 0]]
+        circuit = n_local(3, "x", "crx", entangler_map, reps=2)
+        circuit.draw("mpl")
 
-        We can set different entanglements per layer, by specifing a callable that takes
-        as input the current layer index, and returns the entanglement structure. For example,
-        the following uses different entanglements for odd and even layers:
+    We can set different entanglements per layer, by specifing a callable that takes
+    as input the current layer index, and returns the entanglement structure. For example,
+    the following uses different entanglements for odd and even layers:
 
-        .. plot::
-            :alt: Circuit diagram output by the previous code.
-            :include-source:
-            :context: close-figs
+    .. plot::
+        :alt: Circuit diagram output by the previous code.
+        :include-source:
+        :context: close-figs
 
-            def entanglement(layer_index):
-                if layer_index % 2 == 0:
-                    return [[0, 1], [0, 2]]
-                return [[1, 2]]
+        def entanglement(layer_index):
+            if layer_index % 2 == 0:
+                return [[0, 1], [0, 2]]
+            return [[1, 2]]
 
-            circuit = n_local(3, "x", "cx", entanglement, reps=3, insert_barriers=True)
-            circuit.draw("mpl")
+        circuit = n_local(3, "x", "cx", entanglement, reps=3, insert_barriers=True)
+        circuit.draw("mpl")
 
 
     Args:
@@ -260,7 +260,7 @@ def n_local(
         skip_final_rotation_layer=skip_final_rotation_layer,
         skip_unentangled_qubits=skip_unentangled_qubits,
     )
-    circuit = QuantumCircuit._from_circuit_data(data, add_regs=True, name=name)
+    circuit = QuantumCircuit._from_circuit_data(data, legacy_qubits=True, name=name)
 
     return circuit
 
