@@ -15,21 +15,28 @@
 from qiskit.circuit.quantumcircuit import QuantumCircuit
 
 
-def clifford_3_1():
+def clifford_8_2():
     """
-    Clifford template 3_1:
+    Clifford template 8_2:
 
     .. code-block:: text
 
-             ┌───┐┌───┐┌───┐
-        q_0: ┤ S ├┤ S ├┤ Z ├
-             └───┘└───┘└───┘
+                             ┌───┐
+        q_0: ──■─────────■───┤ S ├───■────────────
+             ┌─┴─┐┌───┐┌─┴─┐┌┴───┴┐┌─┴─┐┌───┐┌───┐
+        q_1: ┤ X ├┤ H ├┤ X ├┤ SDG ├┤ X ├┤ S ├┤ H ├
+             └───┘└───┘└───┘└─────┘└───┘└───┘└───┘
 
     Returns:
         QuantumCircuit: template as a quantum circuit.
     """
-    qc = QuantumCircuit(1)
+    qc = QuantumCircuit(2)
+    qc.cx(0, 1)
+    qc.h(1)
+    qc.cx(0, 1)
     qc.s(0)
-    qc.s(0)
-    qc.z(0)
+    qc.sdg(1)
+    qc.cx(0, 1)
+    qc.s(1)
+    qc.h(1)
     return qc
